summaryrefslogtreecommitdiffstats
path: root/Include/cpython
diff options
context:
space:
mode:
Diffstat (limited to 'Include/cpython')
-rw-r--r--Include/cpython/coreconfig.h13
-rw-r--r--Include/cpython/pylifecycle.h1
2 files changed, 10 insertions, 4 deletions
diff --git a/Include/cpython/pylifecycle.h b/Include/cpython/pylifecycle.h
index 2366c77..a3ab6c9 100644
--- a/Include/cpython/pylifecycle.h
+++ b/Include/cpython/pylifecycle.h
@@ -40,6 +40,7 @@ PyAPI_FUNC(_PyInitError) _Py_InitializeFromWideArgs(
const _PyCoreConfig *config,
int argc,
wchar_t **argv);
+PyAPI_FUNC(_PyInitError) _Py_InitializeMain(void);
PyAPI_FUNC(int) _Py_RunMain(void);
diff --git a/Include/cpython/coreconfig.h b/Include/cpython/coreconfig.h
index a04342e..c2c5566 100644
--- a/Include/cpython/coreconfig.h
+++ b/Include/cpython/coreconfig.h
@@ -398,10 +398,14 @@ typedef struct {
See PEP 552 "Deterministic pycs" for more details. */
wchar_t *check_hash_pycs_mode;
- /* If greater than 0, suppress _PyPathConfig_Calculate() warnings.
+ /* If greater than 0, suppress _PyPathConfig_Calculate() warnings on Unix.
+ The parameter has no effect on Windows.
- If set to -1 (default), inherit Py_FrozenFlag value. */
- int _frozen;
+ If set to -1 (default), inherit !Py_FrozenFlag value. */
+ int pathconfig_warnings;
+
+ /* If equal to 0, stop Python initialization before the "main" phase */
+ int _init_main;
} _PyCoreConfig;
@@ -438,7 +442,8 @@ typedef struct {
.buffered_stdio = -1, \
._install_importlib = 1, \
.check_hash_pycs_mode = NULL, \
- ._frozen = -1}
+ .pathconfig_warnings = -1, \
+ ._init_main = 1}
/* Note: _PyCoreConfig_INIT sets other fields to 0/NULL */
#ifdef __cplusplus